/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.trifork.stamdata.persistence;

import java.io.IOException;

import javax.inject.Inject;
import javax.inject.Provider;
import javax.inject.Singleton;
import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import org.hibernate.Session;
import org.hibernate.Transaction;

@Singleton
public class PersistenceFilter implements Filter
{
	public static String HIBERNATE_SESSION_KEY = "dk.nsi.stamdata.cpr.session";

	@Inject
	private Provider<Session> sessionProvider;

	@Override
	public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException
	{
		// Each request is wrapped in a transaction.

		Session session = null;
		Transaction transaction = null;
		
		try
		{
			session = sessionProvider.get();
			session.beginTransaction();
			transaction = session.beginTransaction();
			transaction.setTimeout(5);

			chain.doFilter(request, response);

			session.getTransaction().commit();
		}
		catch (Exception e)
		{
			try {
			    if (transaction != null) {
			        transaction.rollback();
			    }
			} catch (Exception ex) {
			    ex.printStackTrace();
			}
			// Let other filters handle the exception.
			throw new ServletException(e);
		}
		finally
		{
		    
		}
	}


	@Override
	public void init(FilterConfig config) throws ServletException {}


	@Override
	public void destroy() {}
}
