/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.trifork.stamdata.persistence;

// TODO: This is where I moved these classes Friday morning
//import com.trifork.stamdata.persistence.SikredeFields;
//import com.trifork.stamdata.persistence.SikredeFields.SikredeFieldSpecification;
//import com.trifork.stamdata.persistence.SikredeFields.RecordFieldType;
import com.trifork.stamdata.persistence.RecordSpecification.FieldSpecification;
import com.trifork.stamdata.persistence.RecordSpecification.RecordFieldType;

public class RecordMySQLTableGenerator
{
    public static String createSqlSchema(RecordSpecification recordSpecification)
    {
        RecordMySQLTableGenerator creator = new RecordMySQLTableGenerator(recordSpecification);
        return creator.buildSqlSchema();
    }

    private RecordSpecification recordSpecification;

    private RecordMySQLTableGenerator(RecordSpecification recordSpecification)
    {
        this.recordSpecification = recordSpecification;
    }

    private String buildSqlSchema()
    {
        StringBuilder builder = new StringBuilder();

        builder.append("CREATE TABLE " + recordSpecification.getTable() + " (\n");

        builder.append("\tPID BIGINT(15) AUTO_INCREMENT NOT NULL PRIMARY KEY");

        for (FieldSpecification fieldSpecification: recordSpecification.getFieldSpecs())
        {
            if(fieldSpecification.persistField)
            {
                if(fieldSpecification.type == RecordFieldType.NUMERICAL)
                {
                    builder.append(String.format(",\n\t%s BIGINT", fieldSpecification.name));
                }
                else if(fieldSpecification.type == RecordFieldType.TIMESTAMP)
                {
                    builder.append(String.format(",\n\t%s DATETIME", fieldSpecification.name));
                }
                else if(fieldSpecification.type == RecordSpecification.RecordFieldType.ALPHANUMERICAL)
                {
                    builder.append(String.format(",\n\t%s VARCHAR(%d)", fieldSpecification.name, fieldSpecification.length));
                }
                else
                {
                    throw new AssertionError("Field specification must have a type.");
                }
            }
        }

        builder.append(",\n\tValidFrom DateTime NOT NULL");
        builder.append(",\n\tValidTo DateTime");

        builder.append(",\n\tModifiedDate DateTime NOT NULL");

        builder.append("\n) ENGINE=InnoDB COLLATE=utf8_bin;\n");

        return builder.toString();
    }
}
