/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.trifork.stamdata.persistence;

import javax.inject.Inject;
import javax.inject.Provider;

import org.aopalliance.intercept.MethodInterceptor;
import org.aopalliance.intercept.MethodInvocation;
import org.hibernate.Session;

import com.google.inject.AbstractModule;
import com.google.inject.matcher.Matchers;


class TransactionalInterceptor implements MethodInterceptor
{
    @Inject
    private Provider<Session> sessionProvider;


    @Override
    public Object invoke(MethodInvocation invocation) throws Throwable
    {
        Object result;

        Session session = sessionProvider.get();
        if (!session.getTransaction().isActive())
        {
            try
            {
                session.beginTransaction();
                session.setDefaultReadOnly(true);
                result = invocation.proceed();
                session.getTransaction().commit();
            }
            catch (Exception e)
            {
                try
                {
                    if (session.getTransaction().isActive())
                    {
                        session.getTransaction().rollback();
                    }
                }
                catch (Exception ex)
                {
                    ex.printStackTrace();
                }
                
                throw e;
            }
            finally
            {
                if (session.isOpen()) {
                    session.close();
                }
            }
        }
        else
        {
            result = invocation.proceed();
        }

        return result;
    }
}


class TransactionalModule extends AbstractModule
{
    public void configure()
    {
        TransactionalInterceptor transactionalInterceptor = new TransactionalInterceptor();
        requestInjection(transactionalInterceptor);
        bindInterceptor(Matchers.any(), Matchers.annotatedWith(Transactional.class), transactionalInterceptor);
    }
}
