/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.trifork.stamdata.specs;

import static com.trifork.stamdata.persistence.RecordSpecification.field;

import com.trifork.stamdata.persistence.RecordSpecification;

/**
 * Record specs for nutidige CPR informationer
 */
public class CprRecordSpecs {

    public static final RecordSpecification BARN_RELATION_RECORD_TYPE = RecordSpecification.createSpecification("v2_BarnRelation", "Id",
            field("Id", 21),
            field("CPR", 10),
            field("BarnCPR", 10),
            field("CreatedDate", 10),
            field("ValidTo", 10)
        );

    public static final RecordSpecification FORAELDRE_MYNDIGHED_RELATION_RECORD_TYPE = RecordSpecification.createSpecification("v2_ForaeldreMyndighedRelation", "Id",
            field("Id", 21),
            field("CPR", 10),
            field("TypeKode", 4),
            field("TypeTekst", 50),
            field("RelationCpr", 10), // Kun udfyldt ved Anden indehaver 1 eller 2
            field("CreatedDate", 10),
            field("ValidTo", 10)
    );

    public enum FMRTypeKode {
    	MOR("0003","Mor"),
    	FAR("0004","Far"),
    	AI1("0005","Anden indenhaver 1"),
    	AI2("0006","Anden indenhaver 2");

    	private final String kode;
    	private final String tekst;

    	FMRTypeKode(String kode, String tekst) {
    		this.kode = kode;
    		this.tekst = tekst;
    	}

    	public static FMRTypeKode getFromKode(String kode) {
    		for (FMRTypeKode typekode : values()) {
    			if (typekode.getKode().equals(kode)) {
    				return typekode;
    			}
    		}
    		return null;
    	}

    	public String getKode() {
    		return kode;
    	}

    	public String getTekst() {
    		return tekst;
    	}

    	public boolean isParent() {
    		if (this == MOR || this == FAR) {
    			return true;
    		} else {
    			return false;
    		}

    	}
    	public String getId(String relation) {
    		if (isParent()) {
    			return getTekst().toLowerCase();
    		} else {
    			return relation;
    		}
    	}
    }
}
