/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.trifork.stamdata.authorization.models;


import static com.trifork.stamdata.Preconditions.checkNotNull;

import java.io.IOException;
import java.util.List;

import org.hibernate.Query;
import org.hibernate.Session;

import com.google.inject.Inject;

/**
 * Data access object for authorizations.
 * 
 * This class is thread safe.
 * 
 * @author Thomas Børlum (thb@trifork.com)
 */
public class AuthorizationDao {

	private final Session session;

	@Inject	
	AuthorizationDao(Session session) throws IOException {

		this.session = checkNotNull(session);
	}

	@SuppressWarnings("unchecked")
	public List<Authorization> getAuthorizationsCpr(String cpr) {

		Query query = session.createQuery("FROM Authorization WHERE cpr = :cpr ORDER BY authorizationCode");
		query.setParameter("cpr", cpr);

		List<Authorization> authorizations = query.list();

		return authorizations;
	}
	
	@SuppressWarnings("unchecked")
	public List<Authorization> getAuthorizationsAuthorizationCode(String authorizationCode) {

		Query query = session.createQuery("FROM Authorization WHERE authorizationCode = :authorizationCode ORDER BY authorizationCode");
		query.setParameter("authorizationCode", authorizationCode);

		List<Authorization> authorizations = query.list();

		return authorizations;
	}
}
