/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsi.stamdata.replication.models;

import java.util.List;

import org.hibernate.Query;
import org.hibernate.Session;

import com.google.inject.Inject;


/**
 * Data access layer for the Client Model.
 * 
 * @author Thomas Borlum <thb@trifork.com>
 */
public class ClientDao
{
    private final Session session;


    @Inject
    ClientDao(Session session)
    {
        this.session = session;
    }


    public Client findByCvr(String cvr)
    {
        String ssnlike = "CVR:" + cvr + "-%";
        Query query = session.createQuery("FROM Client WHERE subjectSerialNumber LIKE :subjectSerialNumber");
        query.setParameter("subjectSerialNumber", ssnlike);
        return (Client) query.uniqueResult();
    }


    public boolean delete(String id)
    {
        Query query = session.createQuery("DELETE Client WHERE id = :id");
        query.setParameter("id", id);
        return query.executeUpdate() == 1;
    }


    public Client create(String name, String subjectSerialNumber)
    {
        Client client = new Client(name, subjectSerialNumber);
        session.persist(client);
        return client;
    }


    @SuppressWarnings("unchecked")
    public List<Client> findAll()
    {
        return session.createQuery("FROM Client ORDER BY name").list();
    }


    public void update(Client client)
    {
        session.persist(client);
    }
}
