/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr;

import static com.trifork.stamdata.Preconditions.checkNotNull;

import org.apache.log4j.Logger;
import org.hibernate.Session;

import com.google.inject.Inject;
import com.google.inject.Provider;
import com.trifork.stamdata.ComponentMonitor;
import com.trifork.stamdata.persistence.Transactional;

public class ComponentMonitorImpl implements ComponentMonitor
{
	private static final Logger logger = Logger.getLogger(ComponentMonitorImpl.class);
	private final Provider<Session> sessions;
	
	@Inject
	ComponentMonitorImpl(Provider<Session> sessions)
	{
		this.sessions = checkNotNull(sessions, "sessions");
	}
	
	@Override
	@Transactional
	public boolean isOk()
	{
		try
		{
			// We don't want to cache the result here since the connection might actually
			// be lost at any second.
			
			Session session = sessions.get();
			session.createSQLQuery("SELECT 1 FROM Person LIMIT 1").setCacheable(false).uniqueResult();
			
			return true;
		}
		catch (Exception e)
		{
			logger.error("Could not connect to the database.", e);
			
			return false;
		}
	}
}
