/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.mapping;

import java.math.BigInteger;

import com.trifork.stamdata.persistence.Record;
import com.trifork.stamdata.util.SlaConsts;
import dk.oio.rep.medcom_sundcom_dk.xml.schemas._2007._02._01.AssociatedGeneralPractitionerStructureType;
import dk.sdsd.nsp.slalog.api.SLALogItem;

public class YderregisterRecordToAssociatedGeneralPractitionerMapper {

    public static AssociatedGeneralPractitionerStructureType map(Record record, SLALogItem slaLogItem)
    {
        String email = (String) record.get("EmailYder");
        if (!MedcomValidator.validEmail(email)) {
            email = null;
            if (slaLogItem != null) {
                slaLogItem.addCallParameter(SlaConsts.SLA_PARAM_MUTATED + ".email", "<NULL>");
            }
        }
        String postdistYder = PersonMapper.normalizePostDistrict((String) record.get("PostdistYder"));
        String postCode = PersonMapper.normalizePostCode((String) record.get("PostnrYder"));

        AssociatedGeneralPractitionerStructureType associatedGeneralPractitioner = new AssociatedGeneralPractitionerStructureType();
        associatedGeneralPractitioner.setAssociatedGeneralPractitionerIdentifier(new BigInteger((String) record.get("YdernrYder")));
        associatedGeneralPractitioner.setAssociatedGeneralPractitionerOrganisationName((String) record.get("PrakBetegn"));
        associatedGeneralPractitioner.setDistrictName(postdistYder);
        associatedGeneralPractitioner.setEmailAddressIdentifier(email);
        associatedGeneralPractitioner.setPostCodeIdentifier(postCode);
        associatedGeneralPractitioner.setStandardAddressIdentifier((String) record.get("AdrYder"));
        associatedGeneralPractitioner.setTelephoneSubscriberIdentifier((String) record.get("HvdTlf"));
        
        return associatedGeneralPractitioner;
    }
    
}
