/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2011 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.stamdata.cpr.pvit.v101;

import com.trifork.stamdata.Fetcher;
import com.trifork.stamdata.persistence.Transactional;

import dk.nsi._2011._09._23.stamdatacpr.NamePersonQueryType;
import dk.nsi._2014._03._01.stamdatacpr.PersonLookupResponseType;
import dk.nsi.stamdata.cpr.mapping.PersonMapper.CPRProtectionLevel;
import dk.nsi.stamdata.cpr.mapping.v102.PersonMapper;
import dk.nsi.stamdata.cpr.models.Person;
import dk.nsi.stamdata.cpr.pvit.StamdataPersonResponseFinderCommon;
import dk.nsi.stamdata.cpr.util.UnreliableHandler;
import oio.medcom.cprservice._1_0.PersonInformationStructureType;

import javax.inject.Inject;
import javax.xml.datatype.DatatypeConfigurationException;
import javax.xml.datatype.XMLGregorianCalendar;
import java.sql.SQLException;
import java.util.List;

public class StamdataPersonResponseFinder extends StamdataPersonResponseFinderCommon {
    private final PersonMapper personMapper;

    @Inject
    public StamdataPersonResponseFinder(Fetcher fetcher, PersonMapper personMapper, UnreliableHandler unreliableHandler) {
        super(fetcher, unreliableHandler);
        this.personMapper = personMapper;
    }

    protected PersonMapper getPersonMapper() {
        return personMapper;
    }

    public PersonInformationStructureType mapPerson(Person person, CPRProtectionLevel cprProtection) {
        return personMapper.map(person, cprProtection);
    }

    @Transactional
    public PersonLookupResponseType answerCprRequest(String cvr, String cpr) throws SQLException, DatatypeConfigurationException {
        PersonLookupResponseType response = new PersonLookupResponseType();
        List<PersonInformationStructureType> personInformationStructure = response.getPersonInformationStructure();
        Person person = findPersonForCprRequest(cvr, cpr);
        if (person != null) {
            personInformationStructure.add(mapPerson(person, PersonMapper.CPRProtectionLevel.DoNotCensorCPR));
        }
        return response;
    }

    @Transactional
    public PersonLookupResponseType answerCivilRegistrationNumberListPersonRequest(String cvr, List<String> civilRegistrationNumberList) throws SQLException {
        PersonLookupResponseType response = new PersonLookupResponseType();
        List<PersonInformationStructureType> personInformationStructure = response.getPersonInformationStructure();
        for (Person person : findPersonsForCivilRegistrationNumberListPersonRequest(cvr, civilRegistrationNumberList)) {
            personInformationStructure.add(mapPerson(person, PersonMapper.CPRProtectionLevel.DoNotCensorCPR));
        }
        return response;
    }


    @Transactional
    public PersonLookupResponseType answerBirthDatePersonRequest(String cvr, XMLGregorianCalendar birthDate) throws SQLException, DatatypeConfigurationException {
        PersonLookupResponseType response = new PersonLookupResponseType();
        List<PersonInformationStructureType> personInformationStructure = response.getPersonInformationStructure();
        List<Person> persons = findPersonsForBirthDatePersonRequest(cvr, birthDate);
        for (Person person : persons) {
            personInformationStructure.add(mapPerson(person, PersonMapper.CPRProtectionLevel.CensorCPR));
        }
        return response;
    }

    @Transactional
    public PersonLookupResponseType answerNamePersonRequest(String cvr, NamePersonQueryType namePerson) throws SQLException, DatatypeConfigurationException {
        PersonLookupResponseType response = new PersonLookupResponseType();
        List<PersonInformationStructureType> personInformationStructure = response.getPersonInformationStructure();

        List<Person> persons = findPersonsForNamePersonRequest(cvr, namePerson);
        for (Person person : persons) {
            personInformationStructure.add(mapPerson(person, PersonMapper.CPRProtectionLevel.CensorCPR));
        }
        return response;
    }

}
